/*! \file bitimage.h

  \brief bit-image handring functions

  \author
    Copyright (C) SEIKO EPSON CORPORATION 2010.

    Driver for Epson SIDM Printers

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef   bitimage_h
#define   bitimage_h

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "common.h"

/*! \brief bit-image data information */
typedef struct bm_info_s {
  /* from job_info */
  unsigned int    band_pixel_per_line; /*!< Width of band image in pixels  (band_bytes_per_line x 8) */
  unsigned short  hmove_base;          /*!< Horizontal move base unit for "ESC $" */

  /* printer capability and print mode */
  int             high_speed_mode;     /*!< High Speed mode flag */
  unsigned short  support_pse_bmp;     /*!< Bit-image Print Speed Enhancer support flag (bit-field) */

  /* for cancel_job() */
  unsigned char **bitmap_band_buf;     /*!< Output bitmap data buffer (one band) */
  unsigned int   *bmp_data_size;       /*!< ESC * command bitmap data size (for job cancel) */

  /* from cups_page_header2_t */
  unsigned        dots_per_column;     /*!< Rows per band (cupsRowCount) */
  unsigned        HWResolution_H;      /*!< Horizontal Resolution in dots-per-inch */
  unsigned        HWResolution_V;      /*!< Vertical   Resolution in dots-per-inch */

} bm_info_t;


FUNCTION int is_supported_resolution( unsigned int xreso, unsigned int yreso, unsigned int dots_per_column, int high_speed_mode, unsigned short support_pse_bmp);
FUNCTION int get_bitimage_mode( unsigned int xreso, unsigned int yreso, unsigned int dots_per_column, int high_speed_mode, unsigned short support_pse_bmp, unsigned char *escp_bitimage_mode, int *npass );
FUNCTION int line_feed( unsigned int vreso, unsigned short skip_line_num, unsigned long vmove_base );
FUNCTION int send_band( bm_info_t *bm_info, unsigned short band_line, const unsigned char *band_buf );

#endif /* bitimage_h */
/* end of file */
