/*! \file common.h

  \brief common utility.

  \author
    Copyright (C) SEIKO EPSON CORPORATION 2010.

    Driver for Epson SIDM Printers

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef   common_h
#define   common_h

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <errno.h>
#include <stdio.h>
#include <stdlib.h>

#ifndef MYDEBUG
#define MYDEBUG 0 /*!< debug switch
		    0 debug off
		    1 debug on */
#endif

#define FUNCTION                /*!< Global function mark. */
#define LOCALFUNC static        /*!< File scope local function mark. */

#define LF  0x0a                /*!< Line feed command. */
#define FF  0x0c                /*!< Form feed command. */
#define CR  0x0d                /*!< Caridge return command. */
#define EM  0x19                /*!< Cut sheet feeder control command. */
#define ESC 0x1b                /*!< Escape command for ESC/P. */
#define FS  0x1c                /*!< Escape command for ESC/P. */

#define MAX_STR_BUF 1024        /*!< Popular string buffer size in Byte. */

FUNCTION int is_empty( const unsigned char *buff, unsigned int num );
FUNCTION unsigned long my_round_ul( unsigned long value, int from, int to );
FUNCTION unsigned long my_round_ftoul( float value, int from, int to );
FUNCTION unsigned long my_rounddown_ftoul( float value, int from, int to );

FUNCTION void *my_malloc( size_t size );
FUNCTION void my_free( void *ptr );
FUNCTION void get_my_alloc_counter( int *num_alloc, int *num_free );
FUNCTION int safe_usleep( const unsigned long usec );

#define dbg __FILE__,__LINE__,__FUNCTION__ /*!< for debug */

#if        (0 == MYDEBUG)

#define ASSERT(a)          do{}while(0) /*!< for debug */

#else   /* (0 != MYDEBUG) */

#define ASSERT(a) do{ if(!(a)){ fprintf(stderr, "ERROR: %s:%d:%s: ASSERT: %s\n",dbg, #a); exit(1); } }while(0)

#endif  /* (0 != MYDEBUG) */

#endif /* common_h */
/* end of file */
