/*! \file jobinfo.h

  \brief job information

  \author
    Copyright (C) SEIKO EPSON CORPORATION 2010.

    Driver for Epson SIDM Printers

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef   jobinfo_h
#define   jobinfo_h

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <cups/cups.h>
#include <cups/ppd.h>
#include <cups/raster.h>
#include "option.h"


/*! \brief Job Information parameters */
typedef struct job_info_s {

  /* job informations */

  unsigned short    design_base_reso;
  /*!< Base resolution design unit in this driver.
    command:
    ESC ( U
    ESC ( C
    ESC ( c
  */

  unsigned short    vreso_base;
  /*!< Vertical resolution base unit.
    command:
    ESC ( C
    ESC ( c
  */

  unsigned short    vmove_base;
  /*!< Vertical move base unit for "ESC J"
    n/180 inch : 24pin
    n/216 inch :  9pin
   */
  unsigned short    hmove_base;
  /*!< Horizontal move base unit for "ESC $"
    n/design_base_reso dpi = n/360 inch: 24pin
    n/60 inch :  9pin
   */

  unsigned short    support_pse_bmp;
  /*!< Bitimage Print Speed Enhancer support flag (bit-field)
    0x0001 = category 1 : 120x180, 180x180, 180x240
    0x0002 = (not defined)
    0x0004 = (not defined)
    0x0008 = (not defined)
    :      :       :
    :      :       :
  */

  unsigned char     support_pse_fsx;
  /*!< FSx Print Speed Enhancer support flag
    1=enable
    0=disable
  */

  int               high_speed_mode;
  /*!< High Speed mode flag
    1=Yes
    0=No
  */

  /* page infomations */
  int               page_num;   /*!< Current page number */
  ppd_size_t        page_size;  /*!< CUPS page size parameters */
  cups_raster_t    *ras;        /*!< Raster stream for printing */
  unsigned char    *input_raster_buff; /*!< Input CUPS raster data buffer (one line) */
  unsigned char    *band_buf; /*!< Input CUPS raster data buffer (one band) */
  unsigned char    *bitmap_band_buf; /*!< Output bitmap data buffer (one band) */

  unsigned int      band_pixel_per_line; /*!< Width of page image in pixels */
  unsigned int      band_bytes_per_line; /*!< Number of bytes per line of \a band_buf. */
  unsigned int      lines_per_page;      /*!< Number of lines per page */

  /* band image infomation */
  unsigned int      bmp_data_size; /*!< ESC * command bitmap data size (for job cancel) */

} job_info_t;


FUNCTION void cancel_job(int sig);


#endif /* jobinfo_h */
/* end of file */
