/*! \file option.h

  \brief Option keyword and value information

  \author
    Copyright (C) SEIKO EPSON CORPORATION 2010.

    Driver for Epson SIDM Printers

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
#ifndef   option_h
#define   option_h

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <cups/ppd.h>
#include "common.h"

/* PPD Keywords */
#define PPDKEYPageSize       "PageSize"         /*!< PPD keyword for Media Size */
#define PPDKEYInputSlot      "InputSlot"        /*!< PPD keyword for Media Source */
#define PPDKEYResolution     "Resolution"       /*!< PPD keyword for Device Resolution */

#define PPDKEYPrintDirection "EPPrintDirection" /*!< EPSON private PPD keyword for Print Direction */
#define PPDKEYTopMP          "EPTopMP"          /*!< EPSON private PPD keyword for Top Margin Priority */
#define PPDKEYSpeed          "EPSpeed"          /*!< EPSON private PPD keyword for Print Speed */
#define PPDKEYPacketMode     "EPPackMode"       /*!< EPSON private PPD keyword for Packet Mode */
#define PPDKEYSvRP           "EPSvRP"           /*!< EPSON private PPD keyword for Save Roll Paper */
#define PPDKEYTearOff        "EPTearOff"        /*!< EPSON private PPD keyword for Auto Tear Off */

#define PPDATTRSpPseBmp      "EPSpPseBmp"       /*!< EPSON private PPD attribute  for Support Bitimage Print Speed Enhancer */
#define PPDATTRSpPseFsx      "EPSpPseFsx"       /*!< EPSON private PPD attribute for Support Print Speed Enhancer width FSx */


/*! \brief key and value data structure */
typedef struct key_value_s {
  char key[PPD_MAX_NAME];    /*!< Option keyword, like a "PageSize" */
  char value[PPD_MAX_NAME];  /*!< Value for option keyword, like a "A4" */
} key_value_t;


FUNCTION char *find_key_value( const char *key );
FUNCTION int is_match_key_value( const char *key, char *value );
FUNCTION int is_match_key_value_n( const char *key, char *value, int num );
FUNCTION int set_options( ppd_file_t *ppd );

#if (0 == MYDEBUG)
#define debug_show_option_list()         do{}while(0) /*!< for debug */
#else
FUNCTION void debug_show_option_list( void );
#endif  /* (0 != MYDEBUG) */


#endif /* option_h */
/* end of file */
